Crate kcr_multicluster_crd_antrea_io

Crate kcr_multicluster_crd_antrea_io 

This crate contains kube-rs compatible bindings for Kubernetes custom resources for the multicluster.crd.antrea.io group. Each binding is generated with kopium, updated and released weekly.

Available Custom Resources

multicluster.crd.antrea.io/v1alpha1

  • ClusterInfoImport
  • ClusterSet
  • Gateway
  • LabelIdentity
  • MemberClusterAnnounce
  • MultiClusterConfig
  • ResourceExport
  • ResourceImport

multicluster.crd.antrea.io/v1alpha2

  • ClusterClaim
  • ClusterSet

Modules

v1alpha1
v1alpha2