This crate contains kube-rs compatible bindings for Kubernetes custom resources for the multicluster.crd.antrea.io group. Each binding is generated with kopium, updated and released weekly.
Available Custom Resources
multicluster.crd.antrea.io/v1alpha1
ClusterInfoImportClusterSetGatewayLabelIdentityMemberClusterAnnounceMultiClusterConfigResourceExportResourceImport
multicluster.crd.antrea.io/v1alpha2
ClusterClaimClusterSet